﻿using System;

namespace XmlFileConnector
{
    public class FolderBatch
    {
        #region Properties

        private Folder[] folders;

        /// <summary>
        /// Array of Folders enumerated in current batch
        /// </summary>
        public Folder[] Folders
        {
            get { return folders; }
            set { folders = value; }
        }
        
        #endregion
    }

    public class Folder
    {
        private DateTime lastModifiedTime = DateTime.Now;

        public string Path { get; set; }
        public DateTime LastModifiedTime
        {
            get { return lastModifiedTime; }
            set { lastModifiedTime = value; }
        }
    }

    public class DocumentBatch
    {
        #region Private Members

        private bool includesLastItemInRange;
        private int offset;
        private Document[] documents;
        
        #endregion

        public Document[] Documents
        {
            get { return this.documents; }
            set { this.documents = value; }
        }
        
        /// <summary>
        /// Flag that indicates if this represents the
        /// last mail batch to be enumerated
        /// </summary>
        public bool IncludesLastItemInRange
        {
            get { return includesLastItemInRange; }
            set { includesLastItemInRange = value; }
        }
        
        /// <summary>
        /// If IncludesLastItemInRange is false,
        /// this represents the index to begin enumeration
        /// from to get the next batch
        /// </summary>
        public int Offset
        {
            get { return offset; }
            set { offset = value; }
        }

        public DocumentBatch()
        {
            this.includesLastItemInRange = true;
        }
    }
    
    public class Document
    {
        private DateTime lastModifiedTime = DateTime.Now;

        public string Title { get; set; }
        public string DocumentID { get; set; }
        public string Url { get; set; }
        public DateTime LastModifiedTime { get { return this.lastModifiedTime; } set { this.lastModifiedTime = value; } }
        public Byte[] SecurityDesciptor { get; set; }
        public DocumentProperty[] DocumentProperties { get; set; }
    }

    public class DocumentProperty
    {
        public string PropertyName
        {
            get;
            set;
        }

        public object PropertyValue
        {
            get;
            set;
        }
    }
}
