﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.SharePoint.Administration;

namespace XmlFileConnector.Utils
{
    public class LoggingService : SPDiagnosticsServiceBase
    {
        private static object lockObject = new object();

        public static string DiagnosticAreaName = "XML File Connector";
        private static LoggingService _instance;
        
        public static LoggingService Instance
        {
            get
            {
                if (_instance != null)
                {
                    return _instance;
                }

                lock (lockObject)
                {
                    if (_instance == null)
                    {
                        _instance = new LoggingService();
                    }
                }

                return _instance;
            }
        }

        private LoggingService()
            : base("XML File Connector Logging Service", SPFarm.Local)
        {
        }

        protected override IEnumerable<SPDiagnosticsArea> ProvideAreas()
        {
            List<SPDiagnosticsArea> areas = new List<SPDiagnosticsArea>
            {
                new SPDiagnosticsArea(DiagnosticAreaName, new List<SPDiagnosticsCategory>
                {
                    new SPDiagnosticsCategory("XMLFC_Verbose", TraceSeverity.Verbose, EventSeverity.Verbose),
                    new SPDiagnosticsCategory("XMLFC_Info", TraceSeverity.Medium, EventSeverity.Information),
                    new SPDiagnosticsCategory("XMLFC_Warning", TraceSeverity.High, EventSeverity.Warning),
                    new SPDiagnosticsCategory("XMLFC_Error", TraceSeverity.Unexpected, EventSeverity.Error)
                })
            };

            return areas;
        }

        public static void LogVerbose(string format, params object[] args)
        {
            LogVerbose(String.Format(format, args));
        }

        public static void LogVerbose(string message)
        {
            SPDiagnosticsCategory category = LoggingService.Instance.Areas[DiagnosticAreaName].Categories["XMLFC_Verbose"];
            LoggingService.Instance.WriteTrace(0, category, TraceSeverity.Verbose, message);
        }

        public static void LogInfo(string format, params object[] args)
        {
            LogInfo(String.Format(format, args));
        }

        public static void LogInfo(string message)
        {
            SPDiagnosticsCategory category = LoggingService.Instance.Areas[DiagnosticAreaName].Categories["XMLFC_Info"];
            LoggingService.Instance.WriteTrace(0, category, TraceSeverity.Medium, message);
        }

        public static void LogWarning(string format, params object[] args)
        {
            LogWarning(String.Format(format, args));
        }

        public static void LogWarning(string message)
        {
            SPDiagnosticsCategory category = LoggingService.Instance.Areas[DiagnosticAreaName].Categories["XMLFC_Warning"];
            LoggingService.Instance.WriteTrace(0, category, TraceSeverity.High, message);
        }

        public static void LogError(string format, params object[] args)
        {
            LogError(String.Format(format, args));
        }

        public static void LogError(string message)
        {
            SPDiagnosticsCategory category = LoggingService.Instance.Areas[DiagnosticAreaName].Categories["XMLFC_Error"];
            LoggingService.Instance.WriteTrace(0, category, TraceSeverity.Unexpected, message);
        }
    }
}
