﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Microsoft.Office.Server.Search.Connector.BDC;
using connector = Microsoft.Office.Server.Search.Connector;
using XmlFileConnector.Utils;
using Microsoft.SharePoint.Utilities;

namespace XmlFileConnector
{
    public class XmlDocumentConnector : StructuredRepositorySystemUtility<XmlDocumentProxy>
    {
        protected override XmlDocumentProxy CreateProxy()
        {
            return new XmlDocumentProxy();
        }

        protected override void DisposeProxy(XmlDocumentProxy proxy)
        {
            proxy.Dispose();
        }

        /// <summary>
        /// Sets the folderpath Uri on the proxy.
        /// </summary>
        /// <param name="proxy">XmlDocumentProxy</param>
        /// <param name="connectionString">Server Uri</param>
        protected override void SetConnectionString(XmlDocumentProxy proxy, string connectionString)
        {
            Uri startAddress = new Uri(connectionString);
            
            string originalUrlString = SPHttpUtility.UrlPathDecode(startAddress.OriginalString, false);

            // parse the contents of the connection string to extract the config parameters, and extract the id
            string[] parts = originalUrlString.Split(new string[] { "#" }, StringSplitOptions.RemoveEmptyEntries);

            string folderpath = "";
            string configParams = "";

            if (parts.Length >= 2)
            {
                folderpath = parts[0].Replace("xmldoc:", "").Replace("/", "\\");
                configParams = parts[1];
            }

            proxy.XmlInputFolderPath = folderpath;
            proxy.CrawlId = MD5.CalculateMD5Hash(folderpath);
            
            if (!String.IsNullOrEmpty(configParams))
            {
                string[] configParamsParts = configParams.Split(new string[] { ";;" }, StringSplitOptions.RemoveEmptyEntries);
                if (configParamsParts.Length > 0)
                {
                    foreach (var cp in configParamsParts)
                    {
                        string[] p2 = cp.Split('=');
                        if (p2.Length == 2)
                        {
                            string configParamName = p2[0];
                            string configParamValue = p2[1];

                            if ("x".Equals(configParamName, StringComparison.InvariantCultureIgnoreCase))
                            {
                                proxy.DocumentAndIDPath = configParamValue;
                            }
                            else if ("urielm".Equals(configParamName, StringComparison.InvariantCultureIgnoreCase))
                            {
                                proxy.UriElementName = configParamValue;
                            }
                            else if ("titleelm".Equals(configParamName, StringComparison.InvariantCultureIgnoreCase))
                            {
                                proxy.TitleElementName = configParamValue;
                            }
                        }
                    }
                }
            }
        }

        /// <summary>
        /// Sets certificates on the proxy.
        /// </summary>
        protected override void SetCertificates(XmlDocumentProxy proxy, System.Security.Cryptography.X509Certificates.X509CertificateCollection certifcates)
        {
            throw new NotImplementedException();
        }

        /// <summary>
        /// Sets cookies on the proxy.
        /// </summary>
        protected override void SetCookies(XmlDocumentProxy proxy, System.Net.CookieContainer cookies)
        {
            throw new NotImplementedException();
        }

        /// <summary>
        /// Sets user name and password on the proxy
        /// </summary>
        protected override void SetCredentials(XmlDocumentProxy proxy, string userName, string passWord)
        {
            throw new NotImplementedException();
        }

        protected override void SetProxyServerInfo(XmlDocumentProxy proxy, string proxyServerName, string bypassList, bool bypassProxyForLocalAddress)
        {
            proxy.SetProxyServerInfo(
                proxyServerName,
                bypassList,
                bypassProxyForLocalAddress);
        }
    }
}
